@@ -3,7 +3,7 @@ package Net::Async::UWSGI;
 use strict;
 use warnings;
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 =head1 NAME
 
@@ -11,13 +11,11 @@ Net::Async::UWSGI - support the universal webserver gateway interface protocol i
 
 =head1 VERSION
 
-version 0.004
-
-=head1 SYNOPSIS
+version 0.005
 
 =head1 DESCRIPTION
 
-=head1 METHODS
+See L<Net::Async::UWSGI::Server>.
 
 =cut
 
@@ -25,12 +23,10 @@ version 0.004
 
 __END__
 
-=head1 SEE ALSO
-
 =head1 AUTHOR
 
 Tom Molesworth <cpan@perlsite.co.uk>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2013-2014. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2013-2015. Licensed under the same terms as Perl itself.
