@@ -1,5 +1,5 @@
 package Net::Async::UWSGI::Server::Connection;
-$Net::Async::UWSGI::Server::Connection::VERSION = '0.004';
+$Net::Async::UWSGI::Server::Connection::VERSION = '0.005';
 use strict;
 use warnings;
 
@@ -11,7 +11,7 @@ Net::Async::UWSGI::Server::Connection - represents an incoming connection to a s
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 DESCRIPTION
 
@@ -34,6 +34,8 @@ our %CONTENT_TYPE_HANDLER = (
 	'application/javascript' => 'json',
 );
 
+use constant USE_HTTP_RESPONSE => 0;
+
 =head1 METHODS
 
 =cut
@@ -300,13 +302,36 @@ sub content_handler_json {
 }
 
 my %status = (
+	100 => 'Continue',
+	101 => 'Switching protocols',
+	102 => 'Processing',
 	200 => 'OK',
+	201 => 'Created',
+	202 => 'Accepted',
+	203 => 'Non-authoritative information',
 	204 => 'No content',
+	205 => 'Reset content',
+	206 => 'Partial content',
+	207 => 'Multi-status',
+	208 => 'Already reported',
+	226 => 'IM used',
+	300 => 'Multiple choices',
+	301 => 'Moved permanently',
+	302 => 'Found',
+	303 => 'See other',
+	304 => 'Not modified',
+	305 => 'Use proxy',
+	307 => 'Temporary redirect',
+	308 => 'Permanent redirect',
 	400 => 'Bad request',
+	401 => 'Unauthorised',
+	402 => 'Payment required',
+	403 => 'Forbidden',
 	404 => 'Not found',
+	405 => 'Method not allowed',
 	500 => 'Internal server error',
 );
-use constant USE_HTTP_RESPONSE => 0;
+
 sub write_response {
 	my ($self, $code, $hdr, $body) = @_;
 	my $type = ref($body) ? 'text/javascript' : 'text/plain';
@@ -349,4 +374,4 @@ Tom Molesworth <cpan@perlsite.co.uk>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2013-2014. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2013-2015. Licensed under the same terms as Perl itself.
